@@ -24,6 +24,9 @@ Bio::DB::HTS -- Read SAM/BAM/CRAM database files
  use Bio::DB::HTS;
 
  # high level API
+ # Note that the high level API does not reset the CRAM file pointer to the start
+ # of the file as the method to do so is (at time or writing) not easily accessible.
+ # Therefore a new HTS object may be needed to repeat a query.
  my $hts = Bio::DB::HTS->new(-bam  =>"data/ex1.bam",
                              -fasta=>"data/ex1.fa",
 			     );
@@ -239,37 +242,36 @@ follows:
   Option         Description
   ------         -------------
 
-  -bam           Path to the SAM/BAM/CRAM alignmen file that contains the
-                   alignments (required). A http: or ftp: URL is accepted.
+  -bam           Path to the SAM/BAM/CRAM alignment file that contains the
+                 alignments (required). A http: or ftp: URL is accepted.
 
   -fasta         Path to the Fasta file that contains
-                   the reference sequences (optional). Alternatively,
-                   you may pass any object that supports a seq()
-                   or fetch_seq() method and takes the three arguments
-                   ($seq_id,$start,$end).
+                 the reference sequences (optional). Alternatively,
+                 you may pass any object that supports a seq()
+                 or fetch_seq() method and takes the three arguments
+                 ($seq_id,$start,$end).
 
   -expand_flags  A boolean value. If true then the standard
-                   alignment flags will be broken out as
-                   individual tags such as 'M_UNMAPPED' (default
-                   false).
+                 alignment flags will be broken out as
+                 individual tags such as 'M_UNMAPPED' (default false).
 
   -split_splices A boolean value. If true, then alignments that
-                  are split across splices will be broken out
-                  into a single alignment containing two sub-
-                  alignments (default false).
+                 are split across splices will be broken out
+                 into a single alignment containing two sub-
+                 alignments (default false).
 
-  -split          The same as -split_splices.
+  -split         The same as -split_splices.
 
-  -force_refseq   Always use the reference sequence file to derive the
-                   reference sequence, even when the sequence can be
-                   derived from the MD tag. This is slower, but safer
-                   when working with BAM files derived from buggy aligners
-                   or when the reference contains non-canonical (modified)
-                   bases.
+  -force_refseq  Always use the reference sequence file to derive the
+                 reference sequence, even when the sequence can be
+                 derived from the MD tag. This is slower, but safer
+                 when working with BAM files derived from buggy aligners
+                 or when the reference contains non-canonical (modified)
+                 bases.
 
-  -autoindex      Create an alignment index file if one does not exist
-                   or the current one has a modification date
-                   earlier than the alignment file.
+  -autoindex     Create an alignment index file if one does not exist
+                 or the current one has a modification date
+                 earlier than the alignment file.
 
 An example of a typical new() constructor invocation is:
 
@@ -1137,7 +1139,7 @@ specifying that you want an unlimited cap.
 
 =back
 
-=head2 BAM header methods
+=head2 HTS header methods
 
 The Bio::DB::HTS::Header object contains information regarding the
 reference sequence(s) used to construct the corresponding alignment
@@ -1267,7 +1269,7 @@ Rishi Nag E<lt>rishi@ebi.ac.ukE<gt>
 =cut
 
 package Bio::DB::HTS;
-$Bio::DB::HTS::VERSION = '1.04';
+$Bio::DB::HTS::VERSION = '1.05';
 
 use strict;
 use warnings;
@@ -2066,7 +2068,7 @@ sub _glob_match {
 
 package Bio::DB::HTS::Fai;
 
-$Bio::DB::HTS::Fai::VERSION = '1.04';
+$Bio::DB::HTS::Fai::VERSION = '1.05';
 
 sub open { shift->load(@_) }
 
@@ -2083,7 +2085,7 @@ package Bio::SeqFeature::HTSCoverage;
 
 use base 'Bio::SeqFeature::Lite';
 
-$Bio::SeqFeature::HTSCoverage::VERSION = '1.04';
+$Bio::SeqFeature::HTSCoverage::VERSION = '1.05';
 
 sub coverage {
     my $self = shift;
@@ -2115,6 +2117,8 @@ sub gff3_string {
 
 package Bio::DB::HTSfile;
 
+$Bio::DB::HTS::HTSfile::VERSION = '1.05';
+
 use File::Spec;
 use Cwd;
 use Carp 'croak';
